@@ -1,19 +1,6 @@
-# -*- coding: utf-8 -*-
-#  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
-#
-#  This program is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#  -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
 """
 Parameters bound to  ecs_composex.ecs
@@ -164,7 +151,7 @@ CLUSTER_SG_ID = Parameter(
 SERVICE_GROUP_ID_T = "ServiceGroupId"
 SERVICE_GROUP_ID = Parameter(SERVICE_GROUP_ID_T, Type=SG_ID_TYPE, Default="<none>")
 
-AWS_XRAY_IMAGE = "public.ecr.aws/w1m2m2a3/aws-xray-daemon:latest"
+AWS_XRAY_IMAGE = "public.ecr.aws/xray/aws-xray-daemon:latest"
 XRAY_IMAGE_T = "AWSXRayImage"
 XRAY_IMAGE = Parameter(XRAY_IMAGE_T, Type="String", Default=AWS_XRAY_IMAGE)
 
