@@ -1,28 +1,14 @@
-# -*- coding: utf-8 -*-
-#  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
-#
-#  This program is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#  -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2021 John Mille <john@compose-x.io>
 
 """
 Core ECS Template building
 """
 
-from troposphere import If, Ref, Sub, Tags, GetAtt
-from troposphere import AWS_ACCOUNT_ID, AWS_PARTITION, AWS_REGION, AWS_NO_VALUE
+from troposphere import Ref, Sub, Tags, GetAtt
 from troposphere.ec2 import SecurityGroup
-from troposphere.iam import PolicyType
+from troposphere.iam import Policy
 from troposphere.logs import LogGroup
 
 from ecs_composex.common import build_template
@@ -132,14 +118,14 @@ def create_log_group(family):
             RetentionInDays=Ref(ecs_params.LOG_GROUP_RETENTION),
             LogGroupName=Sub(
                 f"${{{ROOT_STACK_NAME.title}}}/"
-                f"svc/ecs/${{{ecs_params.CLUSTER_NAME_T}}}/${family.logical_name}",
+                f"svc/ecs/${{{ecs_params.CLUSTER_NAME_T}}}/{family.logical_name}",
             ),
         ),
     )
     family.exec_role.Policies.append(
-        PolicyType(
+        Policy(
             f"{family.logical_name}LogGroupAccess",
-            PolicyName=Sub(f"CloudWatchAccessFor${{{ecs_params.SERVICE_NAME_T}}}"),
+            PolicyName=Sub(f"CloudWatchAccessForFamily{family.logical_name}"),
             PolicyDocument={
                 "Version": "2012-10-17",
                 "Statement": [
@@ -232,3 +218,4 @@ def generate_services(settings):
         family.set_volumes()
         create_log_group(family)
         family.handle_logging()
+        family.handle_alarms()
